@@ -50,13 +50,18 @@ bool adf_check_volume(AdfDevice * dev, std::string vol_name,
 list adf_path_to_entry(SEXP extptr, std::string filename, int mode) {
   
   std::string entry_name = "";
+  
+  writable::strings entry_names({
+    "volume", "sector", "header_sectype", "parent", "name", "remainder"
+  });
   writable::list result({
-    "volume"_nm = (int)-1,
-      "sector"_nm = (int)-1,
-      "header_sectype"_nm = (int)-1,
-      "parent"_nm = (int)-1,
-      "name"_nm = writable::strings(r_string(entry_name)),
-      "remainder"_nm = writable::strings(r_string(entry_name))});
+    as_sexp((int)-1),
+    as_sexp((int)-1),
+    as_sexp((int)-1),
+    as_sexp((int)-1),
+    writable::strings(r_string(entry_name)),
+    writable::strings(r_string(entry_name))});
+  result.attr("names") = entry_names;
   
   AdfDevice * dev = get_adf_dev(extptr);
   int cur_vol     = get_adf_vol(extptr);
@@ -128,7 +133,6 @@ list adf_path_to_entry(SEXP extptr, std::string filename, int mode) {
   result["header_sectype"] = as_sexp((int)entry_sectype);
   result["parent"]         = as_sexp((int)parent);
   
-  
   if (((mode & ADF_FI_EXPECT_FILE) != 0) &&
       entry_sectype != ST_FILE) {
     const char * message = "Path does not point to a file";
@@ -175,13 +179,13 @@ bool adf_dir_exists_(SEXP extptr, std::string path) {
 }
 
 [[cpp11::register]]
-list adf_entry_info_(SEXP extptr, std::string path) {
+list adf_entry_info_(SEXP extptr, std::string path, int mode) {
   int sector, vol_num, sectype;
   writable::list result;
   if (Rf_inherits(extptr, "adf_device")) {
     AdfDevice * dev = get_adf_dev(extptr);
     
-    list entry = adf_path_to_entry(extptr, path, 0);
+    list entry = adf_path_to_entry(extptr, path, mode);
     sector  = integers(entry["sector"]).at(0);
     vol_num = integers(entry["volume"]).at(0);
     sectype = integers(entry["header_sectype"]).at(0);
@@ -247,15 +251,19 @@ list adf_con_summary(SEXP extptr) {
   AdfFile * af = get_adffile(extptr);
   int nl = af->fileHdr->nameLen;
   if (nl > MAXNAMELEN) nl = MAXNAMELEN;
-  writable::list result({
-    "description"_nm = (std::string)(std::string(af->fileHdr->fileName).substr(0, nl)),
-    "class"_nm = "adf_file_con",
-    "mode"_nm = af->modeWrite ? "r+b" : "rb",
-    "text"_nm = "binary",
-    "opened"_nm = "opened",
-    "can read"_nm = af->modeRead ? "yes" : "no",
-    "can write"_nm = af->modeWrite ? "yes" : "no"
+  writable::strings summary_names({
+    "description", "class", "mode", "text", "opened", "can read", "can write"
   });
+  writable::list result({
+    writable::strings((r_string)std::string(af->fileHdr->fileName).substr(0, nl)),
+    writable::strings((r_string)"adf_file_con"),
+    writable::strings((r_string)(af->modeWrite ? "r+b" : "rb")),
+    writable::strings((r_string)"binary"),
+    writable::strings((r_string)"opened"),
+    writable::strings((r_string)(af->modeRead ? "yes" : "no")),
+    writable::strings((r_string)(af->modeWrite ? "yes" : "no"))
+  });
+  result.attr("names") = summary_names;
 
   return result;
 }
