@@ -23,4 +23,16 @@ test_that("File existence can be tested for multiple directories", {
     adf_file_exists(vp)
     close(my_device)
   })
-})
\ No newline at end of file
+})
+
+test_that("A new directory can be created using a virtual path or a character", {
+  expect_no_error({
+    my_device <- demo_adf(write_protected = FALSE)
+    target <- virtual_path(my_device, "foobar")
+    target2 <- virtual_path(my_device, "raboof")
+    make_adf_dir(target)
+    make_adf_dir(my_device, target2)
+    make_adf_dir(my_device, "barfoo")
+    close(my_device)
+  })
+})
