@@ -13,8 +13,19 @@ test_that("Copy vp to character works", {
     my_device <- demo_adf()
     vp <- virtual_path(my_device, "s/startup-sequence")
     check_dest <- file.path(tempdir(), adf_entry_name(vp))
-    if (!file.exists(check_dest))
-      copy_adf_entry(vp, tempdir())
+    copy_adf_entry(vp, tempdir())
+    close(my_device)
+    rem <- file.remove(file.path(tempdir(), "startup-sequence"))
+  })
+})
+
+test_that("Copy character to vp works", {
+  expect_no_error({
+    my_device <- demo_adf(write_protected = FALSE)
+    f <- tempfile()
+    file.create(f)
+    vp <- virtual_path(my_device, "DF0:")
+    copy_adf_entry(f, vp)
     close(my_device)
   })
 })
@@ -39,3 +50,14 @@ test_that("Move vp to vp works", {
     close(my_device)
   })
 })
+
+test_that("Move vp to character works", {
+  expect_no_error({
+    my_device <- demo_adf(write_protected = FALSE)
+    vp <- virtual_path(my_device, "s/startup-sequence")
+    f <- tempdir()
+    move_adf_entry(vp, f)
+    close(my_device)
+    rem <- file.remove(file.path(tempdir(), "startup-sequence"))
+  })
+})
